==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomSizePolicy.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomSizePolicy</code></p>
 */
public class DomSizePolicy extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>DomSizePolicy()</code></p>
     */
    public DomSizePolicy(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSizePolicy instance);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>attributeHSizeType()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeHSizeType(){
        return attributeHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeHSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>attributeVSizeType()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeVSizeType(){
        return attributeVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeVSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>clearAttributeHSizeType()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeHSizeType(){
        clearAttributeHSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeHSizeType_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>clearAttributeVSizeType()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeVSizeType(){
        clearAttributeVSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeVSizeType_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>clearElementHSizeType()</code></p>
     */
    @QtUninvokable
    public final void clearElementHSizeType(){
        clearElementHSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHSizeType_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>clearElementHorStretch()</code></p>
     */
    @QtUninvokable
    public final void clearElementHorStretch(){
        clearElementHorStretch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHorStretch_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>clearElementVSizeType()</code></p>
     */
    @QtUninvokable
    public final void clearElementVSizeType(){
        clearElementVSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementVSizeType_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>clearElementVerStretch()</code></p>
     */
    @QtUninvokable
    public final void clearElementVerStretch(){
        clearElementVerStretch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementVerStretch_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>elementHSizeType()const</code></p>
     */
    @QtUninvokable
    public final int elementHSizeType(){
        return elementHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementHSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>elementHorStretch()const</code></p>
     */
    @QtUninvokable
    public final int elementHorStretch(){
        return elementHorStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementHorStretch_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>elementVSizeType()const</code></p>
     */
    @QtUninvokable
    public final int elementVSizeType(){
        return elementVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementVSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>elementVerStretch()const</code></p>
     */
    @QtUninvokable
    public final int elementVerStretch(){
        return elementVerStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementVerStretch_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>hasAttributeHSizeType()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeHSizeType(){
        return hasAttributeHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeHSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>hasAttributeVSizeType()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeVSizeType(){
        return hasAttributeVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeVSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>hasElementHSizeType()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHSizeType(){
        return hasElementHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>hasElementHorStretch()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHorStretch(){
        return hasElementHorStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHorStretch_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>hasElementVSizeType()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementVSizeType(){
        return hasElementVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementVSizeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>hasElementVerStretch()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementVerStretch(){
        return hasElementVerStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementVerStretch_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>setAttributeHSizeType(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeHSizeType(java.lang.@NonNull String a){
        setAttributeHSizeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeHSizeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>setAttributeVSizeType(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeVSizeType(java.lang.@NonNull String a){
        setAttributeVSizeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeVSizeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>setElementHSizeType(int)</code></p>
     */
    @QtUninvokable
    public final void setElementHSizeType(int a){
        setElementHSizeType_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHSizeType_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>setElementHorStretch(int)</code></p>
     */
    @QtUninvokable
    public final void setElementHorStretch(int a){
        setElementHorStretch_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHorStretch_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>setElementVSizeType(int)</code></p>
     */
    @QtUninvokable
    public final void setElementVSizeType(int a){
        setElementVSizeType_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementVSizeType_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>setElementVerStretch(int)</code></p>
     */
    @QtUninvokable
    public final void setElementVerStretch(int a){
        setElementVerStretch_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementVerStretch_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomSizePolicy::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomSizePolicy(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.7-sources.jar: io/qt/uic/ui4/DomSizePolicy.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomSizePolicy</p>
 */
public class DomSizePolicy extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomSizePolicy(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSizePolicy instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeHSizeType(){
        return attributeHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeHSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeVSizeType(){
        return attributeVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeVSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeHSizeType(){
        clearAttributeHSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeHSizeType_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeVSizeType(){
        clearAttributeVSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeVSizeType_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementHSizeType(){
        clearElementHSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHSizeType_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementHorStretch(){
        clearElementHorStretch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHorStretch_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementVSizeType(){
        clearElementVSizeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementVSizeType_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementVerStretch(){
        clearElementVerStretch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementVerStretch_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementHSizeType(){
        return elementHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementHSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementHorStretch(){
        return elementHorStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementHorStretch_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementVSizeType(){
        return elementVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementVSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementVerStretch(){
        return elementVerStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementVerStretch_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeHSizeType(){
        return hasAttributeHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeHSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeVSizeType(){
        return hasAttributeVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeVSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHSizeType(){
        return hasElementHSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHorStretch(){
        return hasElementHorStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHorStretch_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementVSizeType(){
        return hasElementVSizeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementVSizeType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementVerStretch(){
        return hasElementVerStretch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementVerStretch_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeHSizeType(java.lang.String a){
        setAttributeHSizeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeHSizeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setAttributeVSizeType(java.lang.String a){
        setAttributeVSizeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeVSizeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementHSizeType(int a){
        setElementHSizeType_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementHSizeType_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementHorStretch(int a){
        setElementHorStretch_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementHorStretch_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementVSizeType(int a){
        setElementVSizeType_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementVSizeType_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementVerStretch(int a){
        setElementVerStretch_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementVerStretch_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomSizePolicy(QPrivateConstructor p) { super(p); } 
    
}
